summaryrefslogtreecommitdiffstats
path: root/kexi/plugins/macros/kexipart
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit04766b207afba7961d4d802313e426f5a2fbef63 (patch)
treec888ea1027c793e2d0386a7e5a1a0cd077b03cb3 /kexi/plugins/macros/kexipart
parentb6edfe41c9395f2e20784cbf0e630af6426950a3 (diff)
downloadkoffice-04766b207afba7961d4d802313e426f5a2fbef63.tar.gz
koffice-04766b207afba7961d4d802313e426f5a2fbef63.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/koffice@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kexi/plugins/macros/kexipart')
-rw-r--r--kexi/plugins/macros/kexipart/keximacrodesignview.cpp4
-rw-r--r--kexi/plugins/macros/kexipart/keximacrodesignview.h4
-rw-r--r--kexi/plugins/macros/kexipart/keximacroerror.h2
-rw-r--r--kexi/plugins/macros/kexipart/keximacropart.cpp12
-rw-r--r--kexi/plugins/macros/kexipart/keximacropart.h8
-rw-r--r--kexi/plugins/macros/kexipart/keximacroproperty.cpp38
-rw-r--r--kexi/plugins/macros/kexipart/keximacroproperty.h20
-rw-r--r--kexi/plugins/macros/kexipart/keximacrotextview.cpp4
-rw-r--r--kexi/plugins/macros/kexipart/keximacrotextview.h4
-rw-r--r--kexi/plugins/macros/kexipart/keximacroview.cpp6
-rw-r--r--kexi/plugins/macros/kexipart/keximacroview.h4
11 files changed, 53 insertions, 53 deletions
diff --git a/kexi/plugins/macros/kexipart/keximacrodesignview.cpp b/kexi/plugins/macros/kexipart/keximacrodesignview.cpp
index efce73c0..b7e89e9a 100644
--- a/kexi/plugins/macros/kexipart/keximacrodesignview.cpp
+++ b/kexi/plugins/macros/kexipart/keximacrodesignview.cpp
@@ -107,8 +107,8 @@ class KexiMacroDesignView::Private
};
-KexiMacroDesignView::KexiMacroDesignView(KexiMainWindow *mainwin, TQWidget *tqparent, ::KoMacro::Macro* const macro)
- : KexiMacroView(mainwin, tqparent, macro, "KexiMacroDesignView")
+KexiMacroDesignView::KexiMacroDesignView(KexiMainWindow *mainwin, TQWidget *parent, ::KoMacro::Macro* const macro)
+ : KexiMacroView(mainwin, parent, macro, "KexiMacroDesignView")
, d( new Private() )
{
// The table's data-model.
diff --git a/kexi/plugins/macros/kexipart/keximacroerror.h b/kexi/plugins/macros/kexipart/keximacroerror.h
index d902d6a4..e03afbcd 100644
--- a/kexi/plugins/macros/kexipart/keximacroerror.h
+++ b/kexi/plugins/macros/kexipart/keximacroerror.h
@@ -57,7 +57,7 @@ class KexiMacroError : public KexiMacroErrorBase
/**
* Constructor.
*
- * @param mainwin The tqparent @a KexiMainWindow instance.
+ * @param mainwin The parent @a KexiMainWindow instance.
* @param context The @a KoMacro::Context where the error happened.
*/
KexiMacroError(KexiMainWindow* mainwin, KSharedPtr<KoMacro::Context> context);
diff --git a/kexi/plugins/macros/kexipart/keximacropart.cpp b/kexi/plugins/macros/kexipart/keximacropart.cpp
index 1fddbd78..ad9babd3 100644
--- a/kexi/plugins/macros/kexipart/keximacropart.cpp
+++ b/kexi/plugins/macros/kexipart/keximacropart.cpp
@@ -54,8 +54,8 @@ class KexiMacroPart::Private
public:
};
-KexiMacroPart::KexiMacroPart(TQObject *tqparent, const char *name, const TQStringList &l)
- : KexiPart::Part(tqparent, name, l)
+KexiMacroPart::KexiMacroPart(TQObject *parent, const char *name, const TQStringList &l)
+ : KexiPart::Part(parent, name, l)
, d( new Private() )
{
//kdDebug() << "KexiMacroPart::KexiMacroPart() Ctor" << endl;
@@ -123,7 +123,7 @@ void KexiMacroPart::initInstanceActions()
//createSharedAction(Kexi::DesignViewMode, i18n("Execute Macro"), "exec", 0, "data_execute");
}
-KexiViewBase* KexiMacroPart::createView(TQWidget* tqparent, KexiDialogBase* dialog, KexiPart::Item& item, int viewMode, TQMap<TQString,TQString>*)
+KexiViewBase* KexiMacroPart::createView(TQWidget* parent, KexiDialogBase* dialog, KexiPart::Item& item, int viewMode, TQMap<TQString,TQString>*)
{
const TQString itemname = item.name();
//kdDebug() << "KexiMacroPart::createView() itemname=" << itemname << endl;
@@ -140,14 +140,14 @@ KexiViewBase* KexiMacroPart::createView(TQWidget* tqparent, KexiDialogBase* dial
KexiMainWindow *win = dialog->mainWin();
if(win && win->project() && win->project()->dbConnection()) {
if(viewMode == Kexi::DesignViewMode) {
- return new KexiMacroDesignView(win, tqparent, macro);
+ return new KexiMacroDesignView(win, parent, macro);
}
if(viewMode == Kexi::TextViewMode) {
- return new KexiMacroTextView(win, tqparent, macro);
+ return new KexiMacroTextView(win, parent, macro);
}
if(viewMode == Kexi::DataViewMode) {
// Called if the macro should be executed.
- return new KexiMacroView(win, tqparent, macro);
+ return new KexiMacroView(win, parent, macro);
}
}
}
diff --git a/kexi/plugins/macros/kexipart/keximacroproperty.cpp b/kexi/plugins/macros/kexipart/keximacroproperty.cpp
index aed4a9bd..e67794be 100644
--- a/kexi/plugins/macros/kexipart/keximacroproperty.cpp
+++ b/kexi/plugins/macros/kexipart/keximacroproperty.cpp
@@ -53,8 +53,8 @@ class KexiMacroProperty::Private
TQString name;
};
-KexiMacroProperty::KexiMacroProperty(KoProperty::Property* tqparent, KSharedPtr<KoMacro::MacroItem> macroitem, const TQString& name)
- : KoProperty::CustomProperty(tqparent)
+KexiMacroProperty::KexiMacroProperty(KoProperty::Property* parent, KSharedPtr<KoMacro::MacroItem> macroitem, const TQString& name)
+ : KoProperty::CustomProperty(parent)
, d( new Private() )
{
d->macroitem = macroitem;
@@ -164,8 +164,8 @@ KoProperty::Property* KexiMacroProperty::createProperty(KSharedPtr<KoMacro::Macr
* KexiMacroPropertyFactory
*/
-KexiMacroPropertyFactory::KexiMacroPropertyFactory(TQObject* tqparent)
- : KoProperty::CustomPropertyFactory(tqparent)
+KexiMacroPropertyFactory::KexiMacroPropertyFactory(TQObject* parent)
+ : KoProperty::CustomPropertyFactory(parent)
{
}
@@ -173,14 +173,14 @@ KexiMacroPropertyFactory::~KexiMacroPropertyFactory()
{
}
-KoProperty::CustomProperty* KexiMacroPropertyFactory::createCustomProperty(KoProperty::Property* tqparent)
+KoProperty::CustomProperty* KexiMacroPropertyFactory::createCustomProperty(KoProperty::Property* parent)
{
- kdDebug()<<"KexiMacroPropertyFactory::createCustomProperty tqparent="<<tqparent->name()<<endl;
+ kdDebug()<<"KexiMacroPropertyFactory::createCustomProperty parent="<<parent->name()<<endl;
- KoProperty::CustomProperty* customproperty = tqparent->customProperty();
+ KoProperty::CustomProperty* customproperty = parent->customProperty();
KexiMacroProperty* parentcustomproperty = dynamic_cast<KexiMacroProperty*>(customproperty);
if(! parentcustomproperty) {
- kdWarning() << "KexiMacroPropertyFactory::createCustomProperty() tqparent=" << tqparent->name() << " has an invalid customproperty." << endl;
+ kdWarning() << "KexiMacroPropertyFactory::createCustomProperty() parent=" << parent->name() << " has an invalid customproperty." << endl;
return 0;
}
@@ -189,7 +189,7 @@ KoProperty::CustomProperty* KexiMacroPropertyFactory::createCustomProperty(KoPro
const TQString name = parentcustomproperty->name();
Q_ASSERT(! name.isEmpty());
- KexiMacroProperty* macroproperty = new KexiMacroProperty(tqparent, macroitem, name);
+ KexiMacroProperty* macroproperty = new KexiMacroProperty(parent, macroitem, name);
if(! macroproperty->variable().data()) {
delete macroproperty; macroproperty = 0;
return 0;
@@ -232,12 +232,12 @@ class ListBoxItem : public TQListBoxText
virtual ~ListBoxItem() {}
void setEnabled(bool enabled) { m_enabled = enabled; }
virtual int width(const TQListBox* lb) const {
- Q_ASSERT( dynamic_cast<KComboBox*>( lb->tqparent() ) );
- return static_cast<KComboBox*>( lb->tqparent() )->lineEdit()->width() + 2;
+ Q_ASSERT( dynamic_cast<KComboBox*>( lb->parent() ) );
+ return static_cast<KComboBox*>( lb->parent() )->lineEdit()->width() + 2;
}
virtual int height(const TQListBox* lb) const {
- Q_ASSERT( dynamic_cast<KComboBox*>( lb->tqparent() ) );
- return m_enabled ? static_cast<KComboBox*>( lb->tqparent() )->height() + 2 : 0;
+ Q_ASSERT( dynamic_cast<KComboBox*>( lb->parent() ) );
+ return m_enabled ? static_cast<KComboBox*>( lb->parent() )->height() + 2 : 0;
}
private:
bool m_enabled;
@@ -281,7 +281,7 @@ class EditListBoxItem : public ListBoxItem
protected:
virtual void paint(TQPainter* p) {
if(! m_widget) return;
- Q_ASSERT( dynamic_cast<KComboBox*>( listBox()->tqparent() ) );
+ Q_ASSERT( dynamic_cast<KComboBox*>( listBox()->parent() ) );
const int w = width(listBox());
const int h = height(listBox());
m_widget->setFixedSize(w - 2, h - 2);
@@ -342,7 +342,7 @@ class EditListBoxItem : public ListBoxItem
variable->text(), // caption
TQString(), // description
type, // type
- 0 //parentproperty // tqparent
+ 0 //parentproperty // parent
);
m_widget = KoProperty::FactoryManager::self()->createWidgetForProperty(m_prop);
@@ -367,8 +367,8 @@ class EditListBoxItem : public ListBoxItem
class ListBox : public TQListBox
{
public:
- ListBox(KComboBox* tqparent, KexiMacroProperty* macroproperty)
- : TQListBox(tqparent)
+ ListBox(KComboBox* parent, KexiMacroProperty* macroproperty)
+ : TQListBox(parent)
, m_macroproperty(macroproperty)
, m_edititem(0)
{
@@ -501,8 +501,8 @@ class KexiMacroPropertyWidget::Private
ListBox* listbox;
};
-KexiMacroPropertyWidget::KexiMacroPropertyWidget(KoProperty::Property* property, TQWidget* tqparent)
- : KoProperty::Widget(property, tqparent)
+KexiMacroPropertyWidget::KexiMacroPropertyWidget(KoProperty::Property* property, TQWidget* parent)
+ : KoProperty::Widget(property, parent)
, d( new Private() )
{
kdDebug() << "KexiMacroPropertyWidget::KexiMacroPropertyWidget() Ctor" << endl;
diff --git a/kexi/plugins/macros/kexipart/keximacrotextview.cpp b/kexi/plugins/macros/kexipart/keximacrotextview.cpp
index 11d9cee5..e35ee5b2 100644
--- a/kexi/plugins/macros/kexipart/keximacrotextview.cpp
+++ b/kexi/plugins/macros/kexipart/keximacrotextview.cpp
@@ -41,8 +41,8 @@ class KexiMacroTextView::Private
};
-KexiMacroTextView::KexiMacroTextView(KexiMainWindow *mainwin, TQWidget *tqparent, ::KoMacro::Macro* const macro)
- : KexiMacroView(mainwin, tqparent, macro, "KexiMacroTextView")
+KexiMacroTextView::KexiMacroTextView(KexiMainWindow *mainwin, TQWidget *parent, ::KoMacro::Macro* const macro)
+ : KexiMacroView(mainwin, parent, macro, "KexiMacroTextView")
, d( new Private() )
{
TQHBoxLayout* tqlayout = new TQHBoxLayout(this);
diff --git a/kexi/plugins/macros/kexipart/keximacrodesignview.h b/kexi/plugins/macros/kexipart/keximacrodesignview.h
index e982f1bd..3529ea0c 100644
--- a/kexi/plugins/macros/kexipart/keximacrodesignview.h
+++ b/kexi/plugins/macros/kexipart/keximacrodesignview.h
@@ -49,10 +49,10 @@ class KexiMacroDesignView : public KexiMacroView
*
* \param mainwin The \a KexiMainWindow instance this \a KexiViewBase
* belongs to.
* \param tqparent The tqparent widget this widget should be displayed in.
* \param macro The \a KoMacro::Macro instance this view is for.
*/
- KexiMacroDesignView(KexiMainWindow *mainwin, TQWidget *tqparent, ::KoMacro::Macro* const macro);
+ KexiMacroDesignView(KexiMainWindow *mainwin, TQWidget *parent, ::KoMacro::Macro* const macro);
/**
* Destructor.
@@ -49,10 +49,10 @@ class KexiMacroDesignView : public KexiMacroView
* \param mainwin The \a KexiMainWindow instance this \a KexiViewBase
* belongs to.
- * \param tqparent The tqparent widget this widget should be displayed in.
+ * \param parent The parent widget this widget should be displayed in.
* \param macro The \a KoMacro::Macro instance this view is for.
*/
diff --git a/kexi/plugins/macros/kexipart/keximacropart.h b/kexi/plugins/macros/kexipart/keximacropart.h
index 0ea70c06..374679c0 100644
--- a/kexi/plugins/macros/kexipart/keximacropart.h
+++ b/kexi/plugins/macros/kexipart/keximacropart.h
@@ -37,11 +37,11 @@ class KexiMacroPart : public KexiPart::Part
/**
* Constructor.
*
* \param tqparent The tqparent TQObject this part is child of.
* \param name The name this part has.
* \param args Optional list of arguments passed to this part.
*/
- KexiMacroPart(TQObject *tqparent, const char *name, const TQStringList& args);
+ KexiMacroPart(TQObject *parent, const char *name, const TQStringList& args);
/**
* Destructor.
@@ -64,12 +64,12 @@ class KexiMacroPart : public KexiPart::Part
/**
* Create a new view.
*
* \param tqparent The tqparent TQWidget the new view is displayed in.
* \param dialog The \a KexiDialogBase the view is child of.
* \param item The \a KexiPart::Item this view is for.
* \param viewMode The viewmode we like to have a view for.
*/
- virtual KexiViewBase* createView(TQWidget *tqparent,
+ virtual KexiViewBase* createView(TQWidget *parent,
KexiDialogBase* dialog,
KexiPart::Item& item,
int viewMode = Kexi::DesignViewMode,
@@ -37,11 +37,11 @@ class KexiMacroPart : public KexiPart::Part
* Constructor.
*
- * \param tqparent The tqparent TQObject this part is child of.
+ * \param parent The parent TQObject this part is child of.
* \param name The name this part has.
* \param args Optional list of arguments passed to this part.
@@ -64,12 +64,12 @@ class KexiMacroPart : public KexiPart::Part
* Create a new view.
*
- * \param tqparent The tqparent TQWidget the new view is displayed in.
+ * \param parent The parent TQWidget the new view is displayed in.
* \param dialog The \a KexiDialogBase the view is child of.
* \param item The \a KexiPart::Item this view is for.
diff --git a/kexi/plugins/macros/kexipart/keximacroproperty.h b/kexi/plugins/macros/kexipart/keximacroproperty.h
index b80857d1..9419304e 100644
--- a/kexi/plugins/macros/kexipart/keximacroproperty.h
+++ b/kexi/plugins/macros/kexipart/keximacroproperty.h
@@ -47,24 +47,24 @@ class KexiMacroProperty
public:
/** Constructor. */
- explicit KexiMacroProperty(KoProperty::Property* tqparent, KSharedPtr<KoMacro::MacroItem> macroitem, const TQString& name);
+ explicit KexiMacroProperty(KoProperty::Property* parent, KSharedPtr<KoMacro::MacroItem> macroitem, const TQString& name);
/** Destructor. */
virtual ~KexiMacroProperty();
/** @return the tqparent @a KoProperty::Property instance. */
KoProperty::Property* parentProperty() const;
/** This function is called by @ref KoProperty::Property::setValue()
when a custom property is set.
You don't have to modify the property value, it is done by Property class.
- You just have to update child or tqparent properties value (m_property->tqparent()->setValue()).
+ You just have to update child or parent properties value (m_property->parent()->setValue()).
Note that, when calling Property::setValue, you <b>need</b> to set
useCustomProperty (3rd parameter) to false, or there will be infinite recursion. */
virtual void setValue(const TQVariant &value, bool rememberOldValue);
/** This function is called by @ref KoProperty::Property::value()
when a custom property is set and @ref handleValue() is true.
- You should return property's value, taken from tqparent's value.*/
+ You should return property's value, taken from parent's value.*/
virtual TQVariant value() const;
/** Tells whether CustomProperty should be used to get the property's value.
@@ -111,18 +111,18 @@ class KexiMacroPropertyFactory : public KoProperty::CustomPropertyFactory
{
public:
/** Constructor. */
- explicit KexiMacroPropertyFactory(TQObject* tqparent);
+ explicit KexiMacroPropertyFactory(TQObject* parent);
/** Destructor. */
virtual ~KexiMacroPropertyFactory();
/** @return a new instance of custom property for @p tqparent.
Implement this for property types you want to support.
- Use tqparent->type() to get type of the property. */
- virtual KoProperty::CustomProperty* createCustomProperty(KoProperty::Property* tqparent);
+ Use parent->type() to get type of the property. */
+ virtual KoProperty::CustomProperty* createCustomProperty(KoProperty::Property* parent);
/** @return a new instance of custom property for @p property.
Implement this for property editor types you want to support.
- Use tqparent->type() to get type of the property. */
+ Use parent->type() to get type of the property. */
virtual KoProperty::Widget* createCustomWidget(KoProperty::Property* property);
/** Initializes this factory. The factory may register itself at
@@ -144,7 +144,7 @@ class KexiMacroPropertyWidget : public KoProperty::Widget
public:
/** Constructor. */
- explicit KexiMacroPropertyWidget(KoProperty::Property* property, TQWidget* tqparent = 0);
+ explicit KexiMacroPropertyWidget(KoProperty::Property* property, TQWidget* parent = 0);
/** Destructor. */
virtual ~KexiMacroPropertyWidget();
@@ -47,24 +47,24 @@ class KexiMacroProperty
/** Destructor. */
virtual ~KexiMacroProperty();
- /** @return the tqparent @a KoProperty::Property instance. */
+ /** @return the parent @a KoProperty::Property instance. */
KoProperty::Property* parentProperty() const;
/** This function is called by @ref KoProperty::Property::setValue()
@@ -111,18 +111,18 @@ class KexiMacroPropertyFactory : public KoProperty::CustomPropertyFactory
/** Destructor. */
virtual ~KexiMacroPropertyFactory();
- /** @return a new instance of custom property for @p tqparent.
+ /** @return a new instance of custom property for @p parent.
Implement this for property types you want to support.
diff --git a/kexi/plugins/macros/kexipart/keximacrotextview.h b/kexi/plugins/macros/kexipart/keximacrotextview.h
index 5101c30b..0acfa9ef 100644
--- a/kexi/plugins/macros/kexipart/keximacrotextview.h
+++ b/kexi/plugins/macros/kexipart/keximacrotextview.h
@@ -40,10 +40,10 @@ class KexiMacroTextView : public KexiMacroView
*
* \param mainwin The \a KexiMainWindow instance this \a KexiViewBase
* belongs to.
* \param tqparent The tqparent widget this widget should be displayed in.
* \param macro The \a KoMacro::Macro instance this view is for.
*/
- KexiMacroTextView(KexiMainWindow *mainwin, TQWidget *tqparent, ::KoMacro::Macro* const macro);
+ KexiMacroTextView(KexiMainWindow *mainwin, TQWidget *parent, ::KoMacro::Macro* const macro);
/**
* Destructor.
@@ -40,10 +40,10 @@ class KexiMacroTextView : public KexiMacroView
* \param mainwin The \a KexiMainWindow instance this \a KexiViewBase
* belongs to.
- * \param tqparent The tqparent widget this widget should be displayed in.
+ * \param parent The parent widget this widget should be displayed in.
* \param macro The \a KoMacro::Macro instance this view is for.
*/
diff --git a/kexi/plugins/macros/kexipart/keximacroview.cpp b/kexi/plugins/macros/kexipart/keximacroview.cpp
index e13483c1..e9f9cd33 100644
--- a/kexi/plugins/macros/kexipart/keximacroview.cpp
+++ b/kexi/plugins/macros/kexipart/keximacroview.cpp
@@ -62,8 +62,8 @@ class KexiMacroView::Private
};
-KexiMacroView::KexiMacroView(KexiMainWindow *mainwin, TQWidget *tqparent, KoMacro::Macro* const macro, const char* name)
- : KexiViewBase(mainwin, tqparent, (name ? name : "KexiMacroView"))
+KexiMacroView::KexiMacroView(KexiMainWindow *mainwin, TQWidget *parent, KoMacro::Macro* const macro, const char* name)
+ : KexiViewBase(mainwin, parent, (name ? name : "KexiMacroView"))
, d( new Private(macro) )
{
//kdDebug() << "KexiMacroView::KexiMacroView() Ctor" << endl;
@@ -164,7 +164,7 @@ void KexiMacroView::execute(TQObject* sender)
KSharedPtr<KoMacro::Context> context = d->macro->execute(sender);
if(context->hadException()) {
KexiMacroError* error = new KexiMacroError(
- mainWin(), // The tqparent KexiMainWindow
+ mainWin(), // The parent KexiMainWindow
context // The KoMacro::Context where the error occured.
);
error->exec();
diff --git a/kexi/plugins/macros/kexipart/keximacroview.h b/kexi/plugins/macros/kexipart/keximacroview.h
index 0c44419b..f98d394d 100644
--- a/kexi/plugins/macros/kexipart/keximacroview.h
+++ b/kexi/plugins/macros/kexipart/keximacroview.h
@@ -50,10 +50,10 @@ class KexiMacroView : public KexiViewBase
*
* \param mainwin The \a KexiMainWindow instance this \a KexiViewBase
* belongs to.
* \param tqparent The tqparent widget this widget should be displayed in.
* \param macro The \a KoMacro::Macro instance this view is for.
*/
- KexiMacroView(KexiMainWindow *mainwin, TQWidget *tqparent, ::KoMacro::Macro* const macro, const char* name = 0);
+ KexiMacroView(KexiMainWindow *mainwin, TQWidget *parent, ::KoMacro::Macro* const macro, const char* name = 0);
/**
* Destructor.
@@ -50,10 +50,10 @@ class KexiMacroView : public KexiViewBase
* \param mainwin The \a KexiMainWindow instance this \a KexiViewBase
* belongs to.
- * \param tqparent The tqparent widget this widget should be displayed in.
+ * \param parent The parent widget this widget should be displayed in.
* \param macro The \a KoMacro::Macro instance this view is for.
*/